Struct amazon_sp_services::models::recurrence::Recurrence
source · [−]pub struct Recurrence {
pub end_time: String,
pub days_of_week: Option<Vec<DayOfWeek>>,
pub days_of_month: Option<Vec<i32>>,
}Expand description
Recurrence : Repeated occurrence of an event in a time range.
Fields
end_time: StringEnd time of the recurrence.
days_of_week: Option<Vec<DayOfWeek>>Days of the week when recurrence is valid. If the schedule is valid every Monday, input will only contain MONDAY in the list.
days_of_month: Option<Vec<i32>>Days of the month when recurrence is valid.
Implementations
sourceimpl Recurrence
impl Recurrence
sourcepub fn new(end_time: String) -> Recurrence
pub fn new(end_time: String) -> Recurrence
Repeated occurrence of an event in a time range.